hg site extension
 
(Arne Babenhauserheide)
2011-10-20: renamed static to site.

renamed static to site.

diff --git a/README.txt b/README.txt
--- a/README.txt
+++ b/README.txt
@@ -2,6 +2,8 @@ static
 
 Create and/or upload a static copy of the repository.
 
+→ moved to http://draketo.de/proj/hgsite/
+
 The main goal is sharing Mercurial on servers with only FTP access and
 statically served files, while providing the same information as hg
 serve and full solutions like bitbucket and gitorious (naturally
@@ -10,9 +12,9 @@ without the interactivity).
 Install:
 
 * Clone this repo.
-  hg clone http://draketo.de/proj/hgstatic/
+  hg clone http://draketo.de/proj/hgsite/
 * add this to the [extensions] section in your ~/.hgrc
-  static = path/to/static.py
+  site = path/to/site.py
   if you have no [extensions] section, add it.
 
 Usage:
diff --git a/static.py b/static.py
--- a/static.py
+++ b/static.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-"""static
+"""hgsite
 
 Create and/or upload a static copy of the repository.
 
@@ -33,13 +33,13 @@ without the interactivity).
   - Treat branch heads specially: link on the main page.
 
 * Usage:
-  - hg static [--name] [-r] [folder] → parse the static folder for the current revision.
+  - hg site [--name] [-r] [folder] → parse the static folder for the current revision.
     Mimic pull and clone wherever possible: This is a clone to <repo>/static
-  - hg static --upload <FTP-path> [folder] → update and upload the folder == clone/push
+  - hg site --upload <FTP-path> [folder] → update and upload the folder == clone/push
 
 * Idea: hg clone/push ftp://host.tld/path/to/repo → hg static --upload
 
 * Setup a new static repo or update an existing one: hg static --upload ftp://host.tld/path/to/repo
 
 """
 
@@ -429,7 +429,7 @@ def upload(ui, repo, target, ftpstring, 
 
 
 
-def static(ui, repo, target=None, **opts):
+def staticsite(ui, repo, target=None, **opts):
     """Create a static copy of the repository and/or upload it to an FTP server."""
     if repo.root == target:
         ui.warn("static target repo can’t be the current repo")
@@ -447,7 +447,7 @@ def static(ui, repo, target=None, **opts
 
 cmdtable = {
     # "command-name": (function-call, options-list, help-string)
-    "static": (static,
+    "site": (staticsite,
                      [
                       #('r', 'rev', None, 'parse the given revision'),
                       #('a', 'all', None, 'parse all revisions (requires much space)'),
@@ -33,13 +33,13 @@ without the interactivity).
 
-* Idea: hg clone/push ftp://host.tld/path/to/repo → hg static --upload
+* Idea: hg clone/push ftp://host.tld/path/to/repo → hg site --upload
 
@@ -33,13 +33,13 @@ without the interactivity).
 
-* Setup a new static repo or update an existing one: hg static --upload ftp://host.tld/path/to/repo
+* Setup a new static repo or update an existing one: hg site --upload ftp://host.tld/path/to/repo
 
 """